<?
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
// ImpactClub PHP_DATETIME 1.0 beta
//
// class: DATETIME       (1.0) beta
// class: TIMEZONE       (1.0) beta
// class: DATEDST        (1.0) beta
// requirements: NONE
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
//
// developped by Cristian Valentin Ganta
// http://www.impactclub.ro
//
// Free for non-comercial use.
// Please report any BUGS.
//
////////////////////////////////////////////////////////////////////////////////

// regional time zones
$TIMEZONES['region'] = array (
   'America/New_York' => array (
        'stdzone' => 'EST',
        'dstzone' => 'EDT',
        'datedst' => 'us'),
   'Europe/Berlin' => array (
        'stdzone' => 'CET',
        'dstzone' => 'CEST',
        'datedst' => 'eu'),
   'Europe/Bucharest' => array (
        'stdzone' => 'EET',
        'dstzone' => 'EEST',
        'datedst' => 'eu'),
   'Australia/Sydney' => array (
        'stdzone' => 'AEST',
        'dstzone' => 'AEDST',
        'datedst' => 'au')
        );

////////////////////////////////////////////////////////////////////////////////
/// class: DATETIME
////////////////////////////////////////////////////////////////////////////////

class DATETIME {
  var $timestamp;    // unix timestamp in seconds in GMT
  var $timezone;     // time zone object
  var $datedst;      // datedts object;

  // class constructor
  function DATETIME($time=null, $tz=null) {
    $this->setTZ($tz);
    $this->datedst = new DATEDST($this);
    $this->setTime($time);
    }

  // time ------------------------------------------

  // sets local or GMT time
  function setTime($time=null) {
    if (empty($time)) { $this->timestamp=time(); }
    elseif ((is_int($time)) && ($time>0)) { $this->timestamp=$time; }
    elseif (($timestamp=strtotime($time,$this->timestamp))!=-1) {
           $this->timestamp=$timestamp;
           }
    else { $this->timestamp=time(); }
    }

  // returns formated time in TZ
  function getTime($format=null, $tz=null) {
    if (!empty($tz)) { $this->setTZ($tz); }
    if (empty($format)) { $format="l, dS of F Y h:i:s A T"; }
    $format=str_replace("I", $this->datedst->isDST(), $format);
    $tz=$this->getTZ(); $tz=preg_replace("/./i", "\\\\$0", $tz);
    $format=str_replace("T", $tz, $format);
    return gmdate($format, $this->getLocal());
    }

  // timestamp ------------------------------------------

  // returns timestamp in GMT
  function getGMT() { return $this->timestamp; }

  // returns timestamp in current TZ
  function getLocal() {
    $dst=$this->datedst->isDST();
    return $this->timestamp+$this->timezone->stdzone['offset']+3600*$dst;
    }

  // returns timestamp in current TZ (without DST)
  function getLocalStd() { return $this->timestamp+$this->timezone->stdzone['offset']; }

  // timezone ------------------------------------------


  // sets new timezone
  function setTZ($tz=null) {
    if (!$tz) { $this->timezone  = new TIMEZONE(); }
    else {      $this->timezone  = new TIMEZONE($tz); }
    }

  // gets TZ short name
  function getTZ() {
    if ($this->datedst->isDST()) { return $this->timezone->dstzone['key']; }
    else { return $this->timezone->stdzone['key']; }
    }

  // gets TZ short name (without DST)
  function getTZStd() { return $this->timezone->stdzone['key']; }
  
  // timezone name ------------------------------------------

  // gets TZ long name
  function getTZName() {
    if ($this->datedst->isDST()) { return $this->timezone->dstzone['name']; }
    else { return $this->timezone->stdzone['name']; }
    }

  // gets TZ long name (without DST)
  function getTZNameStd() { return $this->timezone->stdzone['name']; }

  // offsets ------------------------------------------
  
  // get TZ offset
  function getOffset() {
    if ($this->datedst->isDST()) { return $this->timezone->dstzone['offset']; }
    else { return $this->timezone->stdzone['offset']; }
    }
  
  // get TZ offset (without DST)
  function getOffsetStd() { return $this->timezone->stdzone['offset']; }
  
  // types ------------------------------------------
  
  // get TZ time
  function getType() {
    if ($this->datedst->isDST()) { return $this->timezone->dstzone['type']; }
    else { return $this->timezone->stdzone['type']; }
    }

  // get TZ time (without DST)
  function getTypeStd() { return $this->timezone->stdzone['type']; }

} // class end /////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////
/// class: TIMEZONE
////////////////////////////////////////////////////////////////////////////////

class TIMEZONE {
  var $region;       // current region
  var $stdzone;      // standard time
  var $dstzone;      // daylight saving time

  // class constructor
  function TIMEZONE($tz=null) {
    $this->region=($tz)?$tz:'UTC';
    $this->setZone('stdzone');
    $this->setZone('dstzone');
    }

  // sets standard and dts timezones
  function setZone($zone) {
    global $TIMEZONES;
    $pointer=&$this->$zone;
    // short name ------------------------------------------------------
    if (isset($TIMEZONES['region'][$this->region][$zone])) { $pointer['key']=$TIMEZONES['region'][$this->region][$zone]; }
    else { $pointer['key']='UTC'; }
    // long name ------------------------------------------------------
    if (isset($TIMEZONES['standard'][$pointer['key']]['name'])) { $pointer['name']=$TIMEZONES['standard'][$pointer['key']]['name']; }
    else { $pointer['name']=@$TIMEZONES['standard']['UTC']['name']; }
    // standard type ------------------------------------------------------
    if (isset($TIMEZONES['standard'][$pointer['key']]['offset'])) { $pointer['type']=$TIMEZONES['standard'][$pointer['key']]['offset']; }
    else { $pointer['type']=@$TIMEZONES['standard']['UTC']['offset']; }
    // offset ------------------------------------------------------
    if (isset($TIMEZONES['offset'][$pointer['type']])) { $pointer['offset']=$TIMEZONES['offset'][$pointer['type']]; }
    else { $pointer['offset']=@$TIMEZONES['offset']['GMT']; }
    }

} // class end /////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////
/// class: DATEDST
////////////////////////////////////////////////////////////////////////////////

class DATEDST {
  var $type;         // DST type
  var $date;         // DATE object
  
  // class constructor
  function DATEDST($date) {
    $this->date=$date;
    global $TIMEZONES;
    if (isset($TIMEZONES['region'][$this->date->timezone->region]['datedst'])) {
       $this->type=$TIMEZONES['region'][$this->date->timezone->region]['datedst'];
       }
    }
    
  // returns 1 if is DST
  function isDST($time=null) {
   switch ($this->type) {
     case 'eu': { return $this->isDST_eu($time); break; }
     case 'us': { return $this->isDST_us($time); break; }
     case 'au': { return $this->isDST_au($time); break; }
     default:   { return 0; }
     }
    }
    
  // DST in Europe
  function isDST_eu($time=null) {
    if (!$time) { $time=$this->date->timestamp; }
    $year=date("Y",$this->date->timestamp);
    $start = (31-( floor ($year * 5 / 4) + 4) % 7);
    $stop  = (31-( floor ($year * 5 / 4) + 1) % 7);
    $start=gmmktime(1,0,0,3,$start,$year,0);
    $stop=gmmktime(1,0,0,10,$stop,$year,0);
    if (($this->date->timestamp>=$start)&&
       ($this->date->timestamp<=$stop)) {
       return 1;
       }
    return 0;
   }

  // DST in United States
  function isDST_us($time=null) {
    if (!$time) { $time=$this->date->timestamp; }
    $year=date("Y",$this->date->timestamp);
    $start = (2+6 * $year - floor ($year / 4) ) % 7 + 1;
    $stop  = (31-( floor ($year * 5 / 4) + 1) % 7);
    $start=gmmktime(2,0,0,4,$start,$year,0);
    $stop=gmmktime(2,0,0,10,$stop,$year,0);
    if (($this->date->getLocalStd()>=$start)&&
       ($this->date->getLocalStd()<=$stop)) {
       return 1;
       }
    return 0;
   }

  // DST in Australia
  function isDST_au($time=null) {
    if (!$time) { $time=$this->date->timestamp; }
    $year=date("Y",$this->date->timestamp);
    $start = (31-( floor ($year * 5 / 4) + 1) % 7);
    $stop  = (31-( floor ($year * 5 / 4) + 4) % 7);
    $start=gmmktime(1,0,0,10,$start,$year,0);
    $stop=gmmktime(1,0,0,3,$stop,$year+1,0);
    if (($this->date->getLocalStd()>=$start)&&
       ($this->date->getLocalStd()<=$stop)) {
       return 1;
       }
    return 0;
   }

} // class end /////////////////////////////////////////////////////////////////

// GMT offsets  ////////////////////////////////////////////////////////////////

$TIMEZONES['offset'] = array (
    'GMT-12:00' => -43200,
    'GMT-11:00' => -39600,
    'GMT-10:00' => -36000,
    'GMT-09:00' => -32400,
    'GMT-08:00' => -28800,
    'GMT-07:00' => -25200,
    'GMT-06:00' => -21600,
    'GMT-05:00' => -18000,
    'GMT-04:00' => -14400,
    'GMT-03:00' => -10800,
    'GMT-02:00' =>  -7200,
    'GMT-01:00' =>  -3600,
    'GMT'       =>      0,
    'GMT+01:00' =>  +3600,
    'GMT+02:00' =>  +7200,
    'GMT+03:00' => +10800,
    'GMT+04:00' => +14400,
    'GMT+05:00' => +18000,
    'GMT+06:00' => +21600,
    'GMT+07:00' => +25200,
    'GMT+08:00' => +28800,
    'GMT+09:00' => +32400,
    'GMT+10:00' => +36000,
    'GMT+11:00' => +39600,
    'GMT+12:00' => +43200,
// non standard offsets
    'GMT-09:30' => -34200,
    'GMT-03:30' => -12600,
    'GMT-09:30' => -34200,
    'GMT+03:30' => +12600,
    'GMT+04:30' => +16200,
    'GMT+05:30' => +19800,
    'GMT+05:45' => +20700,
    'GMT+06:30' => +23400,
    'GMT+09:30' => +34200,
    'GMT+10:30' => +37800,
    'GMT+11:30' => +41400,
    'GMT+12:45' => +45900,
    'GMT+13:00' => +46800,
    'GMT+13:45' => +49500,
    'GMT+14:00' => +50400 );

// standard and daylight saving time zones /////////////////////////////////////

$TIMEZONES['standard'] = array (
// GMT-11:00
    'MIT' => array (
        'offset' => 'GMT-11:00',
        'name'   => 'West Samoa Time'),
    'NUT' => array (
        'offset' => 'GMT-11:00',
        'name'   => 'Niue Time'),
// GMT-10:00
    'HST' => array(
        'offset' => 'GMT-10:00',
        'name'   => 'Hawaii Standard Time'),
    'HAST' => array(
        'offset' => 'GMT-10:00',
        'name'   => 'Hawaii-Aleutian Standard Time'),
    'TKT' => array(
        'offset' => 'GMT-10:00',
        'name'   => 'Tokelau Time'),
    'CKT' => array(
        'offset' => 'GMT-10:00',
        'name'   => 'Cook Is. Time'),
    'TAHT' => array(
        'offset' => 'GMT-10:00',
        'name'   => 'Tahiti Time'),
// GMT-09:00
    'AKST' => array(
        'offset' => 'GMT-09:00',
        'name'   => 'Alaska Standard Time'),
    'GAMT' => array(
        'offset' => 'GMT-09:00',
        'name'   => 'Gambier Time'),
// GMT-08:00
    'PST' => array(
        'offset' => 'GMT-08:00',
        'name'   => 'Pacific Standard Time'),
// GMT-07:00
    'MST' => array(
        'offset' => 'GMT-07:00',
        'name'   => 'Mountain Standard Time'),
// GMT-06:00
    'CST' => array(
        'offset' => 'GMT-06:00',
        'name'   => 'Central Standard Time'),
    'EAST' => array(
        'offset' => 'GMT-06:00',
        'name'   => 'Easter Is. Time'),
    'GALT' => array(
        'offset' => 'GMT-06:00',
        'name'   => 'Galapagos Time'),
// GMT-05:00
    'EST' => array(
        'offset' => 'GMT-05:00',
        'name'   => 'Eastern Standard Time'),
    'COT' => array(
        'offset' => 'GMT-05:00',
        'name'   => 'Colombia Time'),
// GMT-04:00
    'AST' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Atlantic Standard Time'),
    'AMT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Amazon Standard Time'),
    'GYT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Guyana Time'),
    'BOT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Bolivia Time'),
    'CLT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Chile Time'),
    'FKT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Falkland Is. Time'),
    'PYT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Paraguay Time'),
    'VET' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Venezuela Time'),
// GMT-03:00
    'ART' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Argentine Time'),
    'BRT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Brazil Time'),
    'GFT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'French Guiana Time'),
    'WGT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Western Greenland Time'),
    'PMST' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Pierre & Miquelon Standard Time'),
    'UYT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Uruguay Time'),
    'SRT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Suriname Time'),
// GMT-02:00
    'FNT' => array(
        'offset' => 'GMT-02:00',
        'name'   => 'Fernando de Noronha Time'),
// GMT-01:00
    'EGT' => array(
        'offset' => 'GMT-01:00',
        'name'   => 'Eastern Greenland Time'),
    'AZOT' => array(
        'offset' => 'GMT-01:00',
        'name'   => 'Azores Time'),
    'CVT' => array(
        'offset' => 'GMT-01:00',
        'name'   => 'Cape Verde Time'),
// GMT
    'GMT' => array(
        'offset' => 'GMT',
        'name'   => 'Greenwich Mean Time'),
    'WET' => array(
        'offset' => 'GMT',
        'name'   => 'Western European Time'),
    'UTC' => array(
        'offset' => 'GMT',
        'name'   => 'Coordinated Universal Time'),
// GMT+01:00
    'CET' => array(
        'offset' => 'GMT+01:00',
        'name'   => 'Central European Time'),
    'MET' => array(
        'offset' => 'GMT+01:00',
        'name'   => 'Middle Europe Time'),
    'WAT' => array(
        'offset' => 'GMT+01:00',
        'name'   => 'Western African Time'),
// GMT+02:00
    'EET' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'Eastern European Time'),
    'CAT' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'Central African Time'),
    'SAST' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'South Africa Standard Time'),
// GMT+03:00
    'EAT' => array(
        'offset' => 'GMT+03:00',
        'name'   => 'Eastern African Time'),
    'MSK' => array(
        'offset' => 'GMT+03:00',
        'name'   => 'Moscow Standard Time'),
    'SYOT' => array(
        'offset' => 'GMT+03:00',
        'name'   => 'Syowa Time'),
// GMT+04:00
    'AZT' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Azerbaijan Time'),
    'GST' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Gulf Standard Time'),
    'GET' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Georgia Time'),
    'SAMT' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Samara Time'),
    'SCT' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Seychelles Time'),
    'MUT' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Mauritius Time'),
    'RET' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Reunion Time'),
// GMT+05:00
    'TMT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Turkmenistan Time'),
    'KGT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Kirgizstan Time'),
    'TJT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Tajikistan Time'),
    'PKT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Pakistan Time'),
    'UZT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Uzbekistan Time'),
    'YEKT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Yekaterinburg Time'),
    'TFT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'French Southern & Antarctic Lands Time'),
    'MVT' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Maldives Time'),
// GMT+06:00
    'MAWT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Mawson Time'),
    'VOST' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Vostok Time'),
    'ALMT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Alma-Ata Time'),
    'LKT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Sri Lanka Time'),
    'BDT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Bangladesh Time'),
    'NOVT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Novosibirsk Time'),
    'OMST' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Omsk Time'),
    'BTT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Bhutan Time'),
    'IOT' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Indian Ocean Territory Time'),
// GMT+07:00
    'DAVT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Davis Time'),
    'ICT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Indochina Time'),
    'HOVT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Hovd Time'),
    'WIT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'West Indonesia Time'),
    'KRAT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Krasnoyarsk Time'),
    'CXT' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Christmas Island Time'),
// GMT+08:00
    'WST' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Western Standard Time (Australia)'),
    'CHST' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'China Standard Time'),
    'BNT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Brunei Time'),
    'HKT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Hong Kong Time'),
    'IRKT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Irkutsk Time'),
    'MYT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Malaysia Time'),
    'PHT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Philippines Time'),
    'SGT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Singapore Time'),
    'CIT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Central Indonesia Time'),
    'ULAT' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Ulaanbaatar Time'),
// GMT+09:00
    'CHOT' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Choibalsan Time'),
    'TPT' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'East Timor Time'),
    'EIT' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'East Indonesia Time'),
    'KST' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Korea Standard Time'),
    'JST' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Japan Standard Time'),
    'YAKT' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Yakutsk Time'),
    'PWT' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Palau Time'),
// GMT+10:00
    'AEST' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Eastern Standard Time (Australia)'),
    'DDUT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Dumont-d\'Urville Time'),
    'SAKT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Sakhalin Time'),
    'VLAT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Vladivostok Time'),
    'PGT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Papua New Guinea Time'),
    'TRUT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Truk Time'),
    'YAPT' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Yap Time'),
// GMT+11:00
    'MAGT' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Magadan Time'),
    'VUT' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Vanuatu Time'),
    'SBT' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Solomon Is. Time'),
    'KOST' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Kosrae Time'),
    'NCT' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'New Caledonia Time'),
    'PONT' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Ponape Time'),
// GMT+12:00
    'NZST' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'New Zealand Standard Time'),
    'ANAT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Anadyr Time'),
    'PETT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Petropavlovsk-Kamchatski Time'),
    'MHT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Marshall Islands Time'),
    'FJT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Fiji Time'),
    'TVT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Tuvalu Time'),
    'NRT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Nauru Time'),
    'GILT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Gilbert Is. Time'),
    'WAKT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Wake Time'),
    'WFT' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Wallis & Futuna Time'),
// non standard offsets ////////////////////////////////////////////////////////
// GMT-09:30
    'MART' => array(
        'offset' => 'GMT-09:30',
        'name'   => 'Marquesas Time'),
// GMT-03:30
    'NST' => array(
        'offset' => 'GMT-03:30',
        'name'   => 'Newfoundland Standard Time'),
// GMT+03:30
    'IRT' => array(
        'offset' => 'GMT+03:30',
        'name'   => 'Iran Time'),
// GMT+04:30
    'AFT' => array(
        'offset' => 'GMT+04:30',
        'name'   => 'Afghanistan Time'),
// GMT+05:30
    'IST' => array(
        'offset' => 'GMT+05:30',
        'name'   => 'India Standard Time'),
// GMT+05:45
    'NPT' => array(
        'offset' => 'GMT+05:45',
        'name'   => 'Nepal Time'),
// GMT+06:30
    'MMT' => array(
        'offset' => 'GMT+06:30',
        'name'   => 'Myanmar Time'),
    'CCT' => array(
        'offset' => 'GMT+06:30',
        'name'   => 'Cocos Islands Time'),
// GMT+09:30
    'ACT' => array(
        'offset' => 'GMT+09:30',
        'name'   => 'Central Standard Time (Australia)'),
// GMT+10:30
    'LHST' => array(
        'offset' => 'GMT+10:30',
        'name'   => 'Load Howe Standard Time'),
// GMT+11:30
    'NFT' => array(
        'offset' => 'GMT+11:30',
        'name'   => 'Norfolk Time'),
// GMT+12:45
    'CHAST' => array(
        'offset' => 'GMT+12:45',
        'name'   => 'Chatham Standard Time'),
// GMT+13:00
    'PHOT' => array(
        'offset' => 'GMT+13:00',
        'name'   => 'Phoenix Is. Time'),
    'TOT' => array(
        'offset' => 'GMT+13:00',
        'name'   => 'Tonga Time'),
// GMT+14:00
    'LINT' => array(
        'offset' => 'GMT+14:00',
        'name'   => 'Line Is. Time'),
// daylight saving time zones //////////////////////////////////////////////////
// GMT-09:00
    'HADT' => array(
        'offset' => 'GMT-09:00',
        'name'   => 'Hawaii-Aleutian Daylight Time'),
// GMT-08:00
    'AKDT' => array(
        'offset' => 'GMT-08:00',
        'name'   => 'Alaska Daylight Time'),
// GMT-07:00
    'PDT' => array(
        'offset' => 'GMT-07:00',
        'name'   => 'Pacific Daylight Time'),
// GMT-06:00
    'MDT' => array(
        'offset' => 'GMT-06:00',
        'name'   => 'Mountain Daylight Time'),
// GMT-05:00
    'CDT' => array(
        'offset' => 'GMT-05:00',
        'name'   => 'Central Daylight Time'),
    'EASST' => array(
        'offset' => 'GMT-05:00',
        'name'   => 'Easter Is. Summer Time'),
// GMT-04:00
    'EDT' => array(
        'offset' => 'GMT-04:00',
        'name'   => 'Eastern Daylight Time'),
// GMT-03:00
    'ADT' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Atlantic Daylight Time'),
    'CLST' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Chile Summer Time'),
    'FKST' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Falkland Is. Summer Time'),
    'PYST' => array(
        'offset' => 'GMT-03:00',
        'name'   => 'Paraguay Summer Time'),
// GMT-02:00
    'BRST' => array(
        'offset' => 'GMT-02:00',
        'name'   => 'Brazil Summer Time'),
    'WGST' => array(
        'offset' => 'GMT-02:00',
        'name'   => 'Western Greenland Summer Time'),
    'PMDT' => array(
        'offset' => 'GMT-02:00',
        'name'   => 'Pierre & Miquelon Daylight Time'),
// GMT
    'EGST' => array(
        'offset' => 'GMT',
        'name'   => 'Eastern Greenland Summer Time'),
    'AZOST' => array(
        'offset' => 'GMT-01:00',
        'name'   => 'Azores Summer Time'),
// GMT+01:00
    'WEST' => array(
        'offset' => 'GMT+01:00',
        'name'   => 'Western European Summer Time'),
// GMT+02:00
    'CEST' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'Central European Summer Time'),
    'MEST' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'Middle Europe Summer Time'),
    'WAST' => array(
        'offset' => 'GMT+02:00',
        'name'   => 'Western African Summer Time'),
// GMT+03:00
    'EEST' => array(
        'offset' => 'GMT+03:00',
        'name'   => 'Eastern European Summer Time'),
// GMT+04:00
    'MSD' => array(
        'offset' => 'GMT+04:00',
        'name'   => 'Moscow Daylight Time'),
// GMT+05:00
    'AZST' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Azerbaijan Summer Time'),
    'GEST' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Georgia Summer Time'),
    'SAMST' => array(
        'offset' => 'GMT+05:00',
        'name'   => 'Samara Summer Time'),
// GMT+06:00
    'KGST' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Kirgizstan Summer Time'),
    'YEKST' => array(
        'offset' => 'GMT+06:00',
        'name'   => 'Yekaterinburg Summer Time'),
// GMT+07:00
    'ALMST' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Alma-Ata Summer Time'),
    'NOVST' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Novosibirsk Summer Time'),
    'OMSST' => array(
        'offset' => 'GMT+07:00',
        'name'   => 'Omsk Summer Time'),
// GMT+08:00
    'KRAST' => array(
        'offset' => 'GMT+08:00',
        'name'   => 'Krasnoyarsk Summer Time'),
// GMT+09:00
    'IRKST' => array(
        'offset' => 'GMT+09:00',
        'name'   => 'Irkutsk Summer Time'),
// GMT+10:00
    'YAKST' => array(
        'offset' => 'GMT+10:00',
        'name'   => 'Yaktsk Summer Time'),
// GMT+11:00
    'AEDST' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Eastern Summer Time (Australia)'),
    'SAKST' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Sakhalin Summer Time'),
    'VLAST' => array(
        'offset' => 'GMT+11:00',
        'name'   => 'Vladivostok Summer Time'),
// GMT+12:00
    'MAGST' => array(
        'offset' => 'GMT+12:00',
        'name'   => 'Magadan Summer Time'),
// GMT+13:00
    'NZDT' => array(
        'offset' => 'GMT+13:00',
        'name'   => 'New Zealand Daylight Time'),
    'ANAST' => array(
        'offset' => 'GMT+13:00',
        'name'   => 'Anadyr Summer Time'),
    'PETST' => array(
        'offset' => 'GMT+13:00',
        'name'   => 'Petropavlovsk-Kamchatski Summer Time'),
// non standard daylight savinng time zones ////////////////////////////////////
// GMT-02:30
    'NDT' => array(
        'offset' => 'GMT-02:30',
        'name'   => 'Newfoundland Daylight Time'),
// GMT+04:30
    'IRST' => array(
        'offset' => 'GMT+04:30',
        'name'   => 'Iran Sumer Time'),
// GMT+10:30
    'ACST' => array(
        'offset' => 'GMT+10:30',
        'name'   => 'Central Summer Time (Australia)'),
// GMT+11:30
    'LHST' => array(
        'offset' => 'GMT+11:30',
        'name'   => 'Load Howe Summer Time'),
// GMT+13:45
    'CHADT' => array(
        'offset' => 'GMT+13:45',
        'name'   => 'Chatham Daylight Time'),
    );
////////////////////////////////////////////////////////////////////////////////
?>
  